@@ -17,10 +17,10 @@
 INSTALL_DIR="$HOME/build"
 AUTO_APPEND_DATE=0
 SOURCE_DIR="$INSTALL_DIR/src"
-ACTION_GET_COMPILE_INSTALL=1
-ACTION_GET_ONLY=0
+ACTION_GET=1
+ACTION_CONFIGURE=1
 ACTION_COMPILE_INSTALL=1
-SOURCES_CLEAN=0
+ACTION_CLEAN_SOURCE=0
 DEBUG_BUILD=0
 ASAN_BUILD=0
 DEPLOY=1
@@ -44,6 +44,14 @@ SHOTCUT_VERSION=$(date '+%y.%m.%d')
 ENABLE_BIGSH0T=1
 BIGSH0T_HEAD=1
 BIGSH0T_REVISION=
+ENABLE_ZIMG=1
+ZIMG_HEAD=1
+ZIMG_REVISION=
+DAV1D_HEAD=1
+DAV1D_REVISION=
+AOM_HEAD=1
+AOM_REVISION=
+
 
 # QT_INCLUDE_DIR="$(pkg-config --variable=prefix QtCore)/include"
 QT_INCLUDE_DIR=${QTDIR:+${QTDIR}/include}
@@ -156,6 +164,15 @@ function to_key {
     bigsh0t)
       echo 8
     ;;
+    zimg)
+      echo 9
+    ;;
+    dav1d)
+      echo 10
+    ;;
+    aom)
+      echo 11
+    ;;
     *)
       echo UNKNOWN
     ;;
@@ -290,12 +307,12 @@ function read_configuration {
 function set_globals {
   trace "Entering set_globals @ = $@"
   # Set convenience variables.
-  if test 1 = "$ACTION_GET_ONLY" -o 1 = "$ACTION_GET_COMPILE_INSTALL" ; then
+  if test 1 = "$ACTION_GET" ; then
     GET=1
   else
     GET=0
   fi
-  if test 1 = "$ACTION_GET_COMPILE_INSTALL" -o 1 = "$ACTION_COMPILE_INSTALL" ; then
+  if test 1 = "$ACTION_COMPILE_INSTALL" ; then
     COMPILE_INSTALL=1
   else
     COMPILE_INSTALL=0
@@ -311,7 +328,7 @@ function set_globals {
   # Subdirs list, for number of common operations
   # Note, the function to_key depends on this
   if [ -z "$SUBDIRS" ]; then
-    SUBDIRS="AMF nv-codec-headers FFmpeg"
+    SUBDIRS="aom dav1d AMF nv-codec-headers FFmpeg"
     if test "$ENABLE_SWH_PLUGINS" = "1"; then
         SUBDIRS="$SUBDIRS swh-plugins"
     fi
@@ -324,6 +341,9 @@ function set_globals {
     if test "$ENABLE_BIGSH0T" = 1 ; then
         SUBDIRS="$SUBDIRS bigsh0t"
     fi
+    if test "$ENABLE_ZIMG" = 1 ; then
+        SUBDIRS="zimg $SUBDIRS"
+    fi
     SUBDIRS="$SUBDIRS mlt shotcut"
   fi
 
@@ -359,6 +379,9 @@ function set_globals {
   REPOLOCS[7]="git://github.com/GPUOpen-LibrariesAndSDKs/AMF.git"
 #  REPOLOCS[8]="https://bitbucket.org/dandennedy/bigsh0t.git"
   REPOLOCS[8]="https://bitbucket.org/leo_sutic/bigsh0t.git"
+  REPOLOCS[9]="git://github.com/sekrit-twc/zimg.git"
+  REPOLOCS[10]="https://code.videolan.org/videolan/dav1d.git"
+  REPOLOCS[11]="https://aomedia.googlesource.com/aom"
 
   # REPOTYPE Array holds the repo types. (Yes, this might be redundant, but easy for me)
   REPOTYPES[0]="git"
@@ -370,6 +393,9 @@ function set_globals {
   REPOTYPES[6]="git"
   REPOTYPES[7]="git"
   REPOTYPES[8]="git"
+  REPOTYPES[9]="git"
+  REPOTYPES[10]="git"
+  REPOTYPES[11]="git"
 
   # And, set up the revisions
   REVISIONS[0]=""
@@ -399,6 +425,18 @@ function set_globals {
   if test 0 = "$BIGSH0T_HEAD" -a "$BIGSH0T_REVISION" ; then
     REVISIONS[8]="$BIGSH0T_REVISION"
   fi
+  REVISIONS[9]=""
+  if test 0 = "$ZIMG_HEAD" -a "$ZIMG_REVISION" ; then
+    REVISIONS[9]="$ZIMG_REVISION"
+  fi
+  REVISIONS[10]=""
+  if test 0 = "$DAV1D_HEAD" -a "$DAV1D_REVISION" ; then
+    REVISIONS[10]="$DAV1D_REVISION"
+  fi
+  REVISIONS[11]=""
+  if test 0 = "$AOM_HEAD" -a "$AOM_REVISION" ; then
+    REVISIONS[11]="$AOM_REVISION"
+  fi
 
   # Figure out the number of cores in the system. Used both by make and startup script
   CPUS=$(nproc)
@@ -420,7 +458,7 @@ function set_globals {
 
   # set global environment for all jobs
   alias make=mingw32-make
-  export QTDIR="$HOME/Qt/5.15.1/mingw81_64"
+  export QTDIR="$HOME/Qt/5.15.2/mingw81_64"
   export PKG_CONFIG_PATH="$HOME/lib/pkgconfig:$PKG_CONFIG_PATH"
   export PATH="$FINAL_INSTALL_DIR/bin:$PATH"
   export LD_RUN_PATH="$FINAL_INSTALL_DIR/lib"
@@ -433,8 +471,11 @@ function set_globals {
   #####
   # ffmpeg
   CONFIG[0]="./configure --prefix=$FINAL_INSTALL_DIR --disable-static --disable-doc --enable-gpl --enable-version3 --enable-shared --enable-runtime-cpudetect $CONFIGURE_DEBUG_FLAG"
-  CONFIG[0]="${CONFIG[0]} --enable-libtheora --enable-libvorbis --enable-libmp3lame --enable-libx264 --enable-libx265 --enable-libvpx --enable-libopus --enable-libmfx"
+  CONFIG[0]="${CONFIG[0]} --enable-libtheora --enable-libvorbis --enable-libmp3lame --enable-libx264 --enable-libx265 --enable-libvpx --enable-libopus --enable-libmfx --enable-libdav1d --enable-libaom --disable-decoder=libaom_av1"
   # Add optional parameters
+  if [ "$ENABLE_ZIMG" = "1" ]; then
+    CONFIG[0]="${CONFIG[0]} --enable-libzimg"
+  fi
   CONFIG[0]="${CONFIG[0]} $FFMPEG_ADDITIONAL_OPTIONS"
   CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include $CFLAGS"
 
@@ -486,6 +527,30 @@ function set_globals {
   CONFIG[8]="cmake -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -GNinja $CMAKE_DEBUG_FLAG"
   CFLAGS_[8]=$CFLAGS
   LDFLAGS_[8]=$LDFLAGS
+
+  #####
+  # zimg
+  CONFIG[9]="./configure --prefix=$FINAL_INSTALL_DIR"
+  CFLAGS_[9]=$CFLAGS
+  LDFLAGS_[9]=$LDFLAGS
+
+  #####
+  # dav1d
+  CONFIG[10]="meson setup builddir --prefix=$FINAL_INSTALL_DIR --libdir=$FINAL_INSTALL_DIR/lib"
+  if [ "$DEBUG_BUILD" = "1" ]; then
+    CONFIG[10]="${CONFIG[10]} --buildtype=debug"
+  else
+    CONFIG[10]="${CONFIG[10]} --buildtype=release"
+  fi
+  CFLAGS_[10]=$CFLAGS
+  LDFLAGS_[10]=$LDFLAGS
+
+  #####
+  # aom
+  # Use -DCMAKE_POSITION_INDEPENDENT_CODE=ON if -DBUILD_SHARED_LIBS=1 does not work.
+  CONFIG[11]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG -DBUILD_SHARED_LIBS=1 -DCONFIG_AV1_DECODER=0 -DENABLE_EXAMPLES=0 -DENABLE_TESTS=0 ../aom"
+  CFLAGS_[11]=$CFLAGS
+  LDFLAGS_[11]=$LDFLAGS
 }
 
 ######################################################################
@@ -618,7 +683,7 @@ function get_subproject {
               debug "Found git repo, will update"
 
               if ! git diff-index --quiet ${REVISION:-master}; then
-                  die "git repository has local changes, aborting checkout. Consider disabling ACTION_GET_COMPILE_INSTALL or ACTION_GET_ONLY in your build config if you want to compile with these changes"
+                  die "git repository has local changes, aborting checkout. Consider disabling ACTION_GET in your build config if you want to compile with these changes"
               fi
 
               feedback_status "Pulling git sources for $1"
@@ -755,6 +820,9 @@ function configure_compile_install_subproject {
   export LDFLAGS=`lookup LDFLAGS_ $1`
   log LDFLAGS=$LDFLAGS
 
+  # Configure
+  if [ "$ACTION_CONFIGURE" = "1" ]; then
+
   # Configure
   feedback_status Configuring $1
 
@@ -776,18 +844,37 @@ function configure_compile_install_subproject {
     cmd cp -av "amf/public/include/." "$FINAL_INSTALL_DIR/include/AMF"
   fi
 
+  # Special hack for zimg
+  if test "zimg" = "$1" -a ! -e configure ; then
+    debug "Need to create configure for $1"
+    cmd ./autogen.sh || die "Unable to create configure file for $1"
+    if test ! -e configure ; then
+      die "Unable to confirm presence of configure file for $1"
+    fi
+  fi
+
+  # Special hack for aom
+  if test "aom" = "$1"; then
+    cmd mkdir -p ../build-aom
+    cmd cd ../build-aom || die "Unable to change to directory aom/builddir"
+  fi
+
   MYCONFIG=`lookup CONFIG $1`
   if test "$MYCONFIG" != ""; then
     cmd $MYCONFIG || die "Unable to configure $1"
     feedback_status Done configuring $1
   fi
 
+  fi # if [ "$ACTION_CONFIGURE" = "1" ]
+
   # Compile
   feedback_status Building $1 - this could take some time
   if test "movit" = "$1" ; then
     cmd make -j$MAKEJ libmovit.la || die "Unable to build $1"
-  elif test "frei0r" = "$1" -o "bigsh0t" = "$1"; then
-    cmd ninja || die "Unable to build $1"
+  elif test "frei0r" = "$1" -o "bigsh0t" = "$1" -o "aom" = "$1"; then
+    cmd ninja -j $MAKEJ || die "Unable to build $1"
+  elif test "dav1d" = "$1"; then
+    cmd ninja -C builddir -j $MAKEJ || die "Unable to build $1"
   elif test "$MYCONFIG" != ""; then
     cmd make -j$MAKEJ || die "Unable to build $1"
   fi
@@ -807,10 +894,12 @@ function configure_compile_install_subproject {
     cmd install -p -c translations/*.qm "$FINAL_INSTALL_DIR"/share/translations
     cmd install -d "$FINAL_INSTALL_DIR"/share/shotcut
     cmd cp -a src/qml "$FINAL_INSTALL_DIR"/share/shotcut
-  elif test "frei0r" = "$1"; then
+  elif test "frei0r" = "$1" -o "aom" = "$1"; then
     cmd ninja install || die "Unable to install $1"
   elif test "bigsh0t" = "$1" ; then
     cmd install -p -c *.dll "$FINAL_INSTALL_DIR"/lib/frei0r-1  || die "Unable to install $1"
+  elif test "dav1d" = "$1"; then
+    cmd meson install -C builddir || die "Unable to install $1"
   elif test "$MYCONFIG" != "" ; then
     cmd make install || die "Unable to install $1"
   fi
@@ -931,6 +1020,7 @@ function deploy
 
   log Reorganizing installed files
   cmd mv bin/*.dll .
+  cmd mv lib/*.dll .
   if [ "$SDK" = "1" ]; then
     cmd mv bin/*.exe .
   else
@@ -986,7 +1076,6 @@ function deploy
   cmd cp -pr "$QTDIR"/qml lib
   sed -i "s/onClicked()/onClicked(mouse)/" lib/qml/QtQuick/Controls/Private/EditMenu_base.qml
   cmd rm lib/qml/QtQuick/Controls/Private/EditMenu_base.qmlc
-  cmd curl -o lib/qml/QtQuick/Controls.2/Fusion/ComboBox.qml "https://s3.amazonaws.com/misc.meltymedia/shotcut-build/ComboBox.qml"
   cmd cp -pr "$QTDIR"/translations/qt_*.qm share/translations
   cmd cp -pr "$QTDIR"/translations/qtbase_*.qm share/translations
 
@@ -1092,7 +1181,7 @@ function deploy
 function perform_action {
   trace "Entering perform_action @ = $@"
   # Test that may fail goes here, before we do anything
-  if test 1 = "$SOURCES_CLEAN"; then
+  if test 1 = "$ACTION_CLEAN_SOURCE"; then
     clean_dirs
   fi
   if test 1 = "$GET"; then
