@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2020 Meltytech, LLC
+ * Copyright (c) 2012-2021 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -369,7 +369,7 @@ void EncodeDock::loadPresetFromProperties(Mlt::Properties& preset)
                 || vcodec.endsWith("_qsv") || vcodec.endsWith("_videotoolbox") || vcodec.endsWith("_vaapi"))
             // 0 (best, 100%) - 51 (worst)
             ui->videoQualitySpinner->setValue(TO_RELATIVE(51, 0, videoQuality));
-        else if (vcodec.startsWith("libvpx")) // 0 (best, 100%) - 63 (worst)
+        else if (vcodec.startsWith("libvpx") || vcodec.startsWith("libaom-")) // 0 (best, 100%) - 63 (worst)
             ui->videoQualitySpinner->setValue(TO_RELATIVE(63, 0, videoQuality));
         else // 1 (best, NOT 100%) - 31 (worst)
             ui->videoQualitySpinner->setValue(TO_RELATIVE(31, 1, videoQuality));
@@ -730,7 +730,7 @@ Mlt::Properties* EncodeDock::collectProperties(int realtime)
                 case RateControlQuality: {
                     if (vcodec == "libx264") {
                         setIfNotSet(p, "crf", TO_ABSOLUTE(51, 0, vq));
-                    } else if (vcodec.startsWith("libvpx")) {
+                    } else if (vcodec.startsWith("libvpx") || vcodec.startsWith("libaom-")) {
                         setIfNotSet(p, "crf", TO_ABSOLUTE(63, 0, vq));
                         setIfNotSet(p, "vb", 0); // VP9 needs this to prevent constrained quality mode.
                     } else if (vcodec.endsWith("_vaapi")) {
@@ -746,7 +746,7 @@ Mlt::Properties* EncodeDock::collectProperties(int realtime)
                 case RateControlConstrained: {
                     if (vcodec == "libx264") {
                         setIfNotSet(p, "crf", TO_ABSOLUTE(51, 0, vq));
-                    } else if (vcodec.startsWith("libvpx")) {
+                    } else if (vcodec.startsWith("libvpx") || vcodec.startsWith("libaom-")) {
                         setIfNotSet(p, "crf", TO_ABSOLUTE(63, 0, vq));
                     } else if (vcodec.endsWith("_qsv") || vcodec.endsWith("_videotoolbox")) {
                         setIfNotSet(p, "vb", qRound(cvbr));
@@ -765,7 +765,7 @@ Mlt::Properties* EncodeDock::collectProperties(int realtime)
                 setIfNotSet(p, "g", ui->gopSpinner->value());
                 setIfNotSet(p, "bf", ui->bFramesSpinner->value());
                 if (ui->strictGopCheckBox->isChecked()) {
-                    if (vcodec.startsWith("libvpx"))
+                    if (vcodec.startsWith("libvpx") || vcodec.startsWith("libaom-"))
                         setIfNotSet(p, "keyint_min", ui->gopSpinner->value());
                     else
                         setIfNotSet(p, "sc_threshold", 0);
@@ -920,11 +920,10 @@ MeltJob* EncodeDock::createMeltJob(Mlt::Producer* service, const QString& target
     // get temp filename
     QScopedPointer<QTemporaryFile> tmp{Util::writableTemporaryFile(target)};
     tmp->open();
-    tmp->close();
     QString fileName = tmp->fileName();
-    tmp->remove();
     auto isProxy = ui->previewScaleCheckBox->isChecked() && Settings.proxyEnabled();
-    MLT.saveXML(fileName, service, false /* without relative paths */, nullptr, isProxy);
+    MLT.saveXML(fileName, service, false /* without relative paths */, tmp.get(), isProxy);
+    tmp->close();
 
     // parse xml
     QFile f1(fileName);
@@ -1389,6 +1388,11 @@ void EncodeDock::on_encodeButton_clicked()
         return;
     }
     bool seekable = MLT.isSeekable(fromProducer());
+
+    if (seekable && checkForMissingFiles()) {
+        return;
+    }
+
     QString directory = Settings.encodePath();
     if (!m_extension.isEmpty()) {
         if (!MAIN.fileName().isEmpty()) {
@@ -1963,7 +1967,7 @@ void EncodeDock::on_videoQualitySpinner_valueChanged(int vq)
     QString s;
     if (vcodec == "libx264" || vcodec == "libx265") {
         s = QString("crf=%1").arg(TO_ABSOLUTE(51, 0, vq));
-    } else if (vcodec.startsWith("libvpx")) {
+    } else if (vcodec.startsWith("libvpx") || vcodec.startsWith("libaom-")) {
         s = QString("crf=%1").arg(TO_ABSOLUTE(63, 0, vq));
     } else if (vcodec.contains("nvenc")) {
         if (ui->videoRateControlCombo->currentIndex() == RateControlQuality)
@@ -2042,3 +2046,45 @@ bool EncodeDock::detectHardwareEncoders()
     }
     return !hwlist.isEmpty();
 }
+
+bool EncodeDock::checkForMissingFiles()
+{
+    Mlt::Producer* service = fromProducer();
+    if (!service) {
+        service = MAIN.playlist();
+    }
+    if (!service) {
+        LOG_ERROR() << "Encode: No service to encode";
+        return true;
+    }
+    QScopedPointer<QTemporaryFile> tmp;
+    if (MAIN.fileName().isEmpty()) {
+        tmp.reset(Util::writableTemporaryFile(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/"));
+    } else {
+        QFileInfo info(MAIN.fileName());
+        QString templateFileName = QString("%1.XXXXXX").arg(QCoreApplication::applicationName());
+        tmp.reset(new QTemporaryFile(info.dir().filePath(templateFileName)));
+    }
+    tmp->open();
+    QString fileName = tmp->fileName();
+    auto isProxy = ui->previewScaleCheckBox->isChecked() && Settings.proxyEnabled();
+    MLT.saveXML(fileName, service, false /* without relative paths */, tmp.get(), isProxy);
+    tmp->close();
+    MltXmlChecker checker;
+    if (!checker.check(fileName)) {
+        LOG_ERROR() << "Encode: Unable to check XML - skipping check";
+    } else if (checker.unlinkedFilesModel().rowCount() > 0) {
+        QMessageBox dialog(QMessageBox::Critical,
+           qApp->applicationName(),
+           tr("Your project is missing some files.\n\n"
+              "Save your project, close it, and reopen it.\n"
+              "Shotcut will attempt to repair your project."),
+           QMessageBox::Ok,
+           this);
+        dialog.setWindowModality(QmlApplication::dialogModality());
+        dialog.setDefaultButton(QMessageBox::Ok);
+        dialog.exec();
+        return true;
+    }
+    return false;
+}
