@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2020 Meltytech, LLC
+ * Copyright (c) 2012-2021 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -252,7 +252,7 @@ void PlaylistDock::replaceClipsWithHash(const QString& hash, Mlt::Producer& prod
     }
     auto n = producers.size();
     if (n > 1) {
-        MAIN.undoStack()->beginMacro(tr("Replace %1 playlist items").arg(n));
+        MAIN.undoStack()->beginMacro(tr("Replace %n playlist items", nullptr, n));
     }
     for (auto& clip : producers) {
         Util::applyCustomProperties(producer, clip.parent(), clip.get_in(), clip.get_out());
@@ -383,7 +383,7 @@ void PlaylistDock::on_actionAppendCut_triggered()
             ProxyManager::generateIfNotExists(producer);
             MAIN.undoStack()->push(
                 new Playlist::AppendCommand(m_model, MLT.XML(&producer)));
-            MLT.producer()->set(kPlaylistIndexProperty, m_model.playlist()->count());
+            setPlaylistIndex(MLT.producer(), m_model.playlist()->count() - 1);
             setUpdateButtonEnabled(true);
         } else {
             DurationDialog dialog(this);
@@ -393,7 +393,7 @@ void PlaylistDock::on_actionAppendCut_triggered()
                 if (MLT.producer()->get("mlt_service") && !strcmp(MLT.producer()->get("mlt_service"), "avformat"))
                     MLT.producer()->set("mlt_service", "avformat-novalidate");
                 MAIN.undoStack()->push(new Playlist::AppendCommand(m_model, MLT.XML()));
-                MLT.producer()->set(kPlaylistIndexProperty, m_model.playlist()->count());
+                setPlaylistIndex(MLT.producer(), m_model.playlist()->count() - 1);
                 setUpdateButtonEnabled(true);
             }
         }
@@ -431,7 +431,7 @@ void PlaylistDock::on_actionUpdate_triggered()
         if (MLT.isSeekable()) {
             ProxyManager::generateIfNotExists(*MLT.producer());
             MAIN.undoStack()->push(new Playlist::UpdateCommand(m_model, MLT.XML(), index.row()));
-            MLT.producer()->set(kPlaylistIndexProperty, index.row() + 1);
+            setPlaylistIndex(MLT.producer(), index.row());
             setUpdateButtonEnabled(true);
         }
         else {
@@ -443,7 +443,7 @@ void PlaylistDock::on_actionUpdate_triggered()
                 if (MLT.producer()->get("mlt_service") && !strcmp(MLT.producer()->get("mlt_service"), "avformat"))
                     MLT.producer()->set("mlt_service", "avformat-novalidate");
                 MAIN.undoStack()->push(new Playlist::UpdateCommand(m_model, MLT.XML(), index.row()));
-                MLT.producer()->set(kPlaylistIndexProperty, index.row() + 1);
+                setPlaylistIndex(MLT.producer(), index.row());
                 setUpdateButtonEnabled(true);
             }
         }
@@ -461,7 +461,7 @@ void PlaylistDock::on_removeButton_clicked()
     QList<int> rowsRemoved;
     int n = m_view->selectionModel()->selectedIndexes().size();
     if (n > 1)
-        MAIN.undoStack()->beginMacro(tr("Remove %1 playlist items").arg(n));
+        MAIN.undoStack()->beginMacro(tr("Remove %n playlist items", nullptr, n));
     foreach (auto index, m_view->selectionModel()->selectedIndexes()) {
         int row = index.row();
         if (!rowsRemoved.contains(row)) {
@@ -480,7 +480,7 @@ void PlaylistDock::on_removeButton_clicked()
         MAIN.undoStack()->endMacro();
     if (rowsRemoved.contains(MLT.producer()->get_int(kPlaylistIndexProperty))) {
         // Remove the playlist index property on the producer.
-
+        resetPlaylistIndex();
         setUpdateButtonEnabled(false);
     }
 }
@@ -515,6 +515,15 @@ void PlaylistDock::onProducerOpened()
 {
     if (!MLT.isMultitrack())
         ui->addButton->setEnabled(true);
+    if (MLT.producer() && MLT.producer()->is_valid()) {
+        auto row = MLT.producer()->get_int(kPlaylistIndexProperty) - 1;
+        if (row < 0 && m_model.rowCount() > 0) {
+            resetPlaylistIndex();
+            emit m_model.dataChanged(m_model.createIndex(0, PlaylistModel::COLUMN_THUMBNAIL),
+                m_model.createIndex(m_model.playlist()->count() - 1, PlaylistModel::COLUMN_THUMBNAIL),
+                QVector<int>() << PlaylistModel::COLUMN_THUMBNAIL);
+        }
+    }
 }
 
 void PlaylistDock::onInChanged()
@@ -545,9 +554,10 @@ void PlaylistDock::on_actionOpen_triggered()
     if (i) {
         Mlt::Producer* p = new Mlt::Producer(i->producer);
         p->set_in_and_out(i->frame_in, i->frame_out);
-        p->set(kPlaylistIndexProperty, index.row() + 1);
+        setPlaylistIndex(p, index.row());
         emit clipOpened(p, Settings.playlistAutoplay());
         delete i;
+        m_iconsView->resetMultiSelect();
     }
 }
 
@@ -581,10 +591,11 @@ void PlaylistDock::viewDoubleClicked(const QModelIndex &index)
         } else {
             Mlt::Producer* p = new Mlt::Producer(i->producer);
             p->set_in_and_out(i->frame_in, i->frame_out);
-            p->set(kPlaylistIndexProperty, index.row() + 1);
+            setPlaylistIndex(p, index.row());
             emit clipOpened(p, Settings.playlistAutoplay());
         }
         delete i;
+        m_iconsView->resetMultiSelect();
     }
 }
 
@@ -595,6 +606,7 @@ void PlaylistDock::on_actionGoto_triggered()
     if (i) {
         emit itemActivated(i->start);
         delete i;
+        m_iconsView->resetMultiSelect();
     }
 }
 
@@ -673,7 +685,7 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                 if (first) {
                     first = false;
                     if (!MLT.producer() || !MLT.producer()->is_valid()) {
-                        MAIN.open(path);
+                        MAIN.open(path, nullptr, false);
                         if (MLT.producer() && MLT.producer()->is_valid()) {
                             producer = MLT.producer();
                             first = true;
@@ -708,7 +720,6 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                 if (first) {
                     first = false;
                     setIndex(0);
-                    on_actionOpen_triggered();
                     resetIndex = false;
                 }
             }
@@ -725,10 +736,10 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                 ProxyManager::generateIfNotExists(p);
                 if (row == -1) {
                     MAIN.undoStack()->push(new Playlist::AppendCommand(m_model, MLT.XML(&p)));
-                    MLT.producer()->set(kPlaylistIndexProperty, m_model.playlist()->count());
+                    setPlaylistIndex(MLT.producer(), m_model.playlist()->count() - 1);
                 } else {
                     MAIN.undoStack()->push(new Playlist::InsertCommand(m_model, MLT.XML(&p), row));
-                    MLT.producer()->set(kPlaylistIndexProperty, row + 1);
+                    setPlaylistIndex(MLT.producer(), row);
                 }
                 setUpdateButtonEnabled(true);
             } else {
@@ -956,6 +967,12 @@ void PlaylistDock::resetPlaylistIndex()
 {
     if (MLT.producer())
         MLT.producer()->set(kPlaylistIndexProperty, nullptr, 0);
+    // Clear the old values
+    for (int j = 0; j < m_model.playlist()->count(); ++j) {
+        Mlt::Producer clip(m_model.playlist()->get_clip(j));
+        clip.parent().Mlt::Properties::clear(kPlaylistIndexProperty);
+    }
+    setUpdateButtonEnabled(false);
 }
 
 void PlaylistDock::emitDataChanged(const QVector<int> &roles)
@@ -966,6 +983,16 @@ void PlaylistDock::emitDataChanged(const QVector<int> &roles)
     emit m_model.dataChanged(index, index, roles);
 }
 
+void PlaylistDock::setPlaylistIndex(Mlt::Producer* producer, int row)
+{
+    // Clear the old values
+    for (int j = 0; j < m_model.playlist()->count(); ++j) {
+        Mlt::Producer clip(m_model.playlist()->get_clip(j));
+        clip.parent().Mlt::Properties::clear(kPlaylistIndexProperty);
+    }
+    producer->set(kPlaylistIndexProperty, row + 1);
+}
+
 #include "playlistdock.moc"
 
 void PlaylistDock::on_tilesButton_clicked()
@@ -1047,11 +1074,13 @@ void PlaylistDock::on_actionCopy_triggered()
     if (!index.isValid() || !m_model.playlist()) return;
     Mlt::ClipInfo* i = m_model.playlist()->clip_info(index.row());
     if (i) {
+        resetPlaylistIndex();
         QString xml = MLT.XML(i->producer);
         Mlt::Producer* p = new Mlt::Producer(MLT.profile(), "xml-string", xml.toUtf8().constData());
         p->set_in_and_out(i->frame_in, i->frame_out);
         emit clipOpened(p);
         delete i;
+        m_iconsView->resetMultiSelect();
     }
 }
 
