@@ -34,6 +34,7 @@ class ShotcutSettings : public QObject
     Q_PROPERTY(bool timelineSnap READ timelineSnap WRITE setTimelineSnap NOTIFY timelineSnapChanged)
     Q_PROPERTY(bool timelineCenterPlayhead READ timelineCenterPlayhead WRITE setTimelineCenterPlayhead NOTIFY timelineCenterPlayheadChanged)
     Q_PROPERTY(bool timelineScrollZoom READ timelineScrollZoom WRITE setTimelineScrollZoom NOTIFY timelineScrollZoomChanged)
+    Q_PROPERTY(bool timelineFramebufferWaveform READ timelineFramebufferWaveform WRITE setTimelineFramebufferWaveform NOTIFY timelineFramebufferWaveformChanged)
     Q_PROPERTY(QString openPath READ openPath WRITE setOpenPath NOTIFY openPathChanged)
     Q_PROPERTY(QString savePath READ savePath WRITE setSavePath NOTIFY savePathChanged)
     Q_PROPERTY(QString playlistThumbnails READ playlistThumbnails WRITE setPlaylistThumbnails NOTIFY playlistThumbnailsChanged)
@@ -163,6 +164,8 @@ public:
     void setTimelineTrackHeight(int);
     bool timelineScrollZoom() const;
     void setTimelineScrollZoom(bool);
+    bool timelineFramebufferWaveform() const;
+    void setTimelineFramebufferWaveform(bool);
 
     // filter
     QString filterFavorite(const QString& filterName);
@@ -235,6 +238,7 @@ signals:
     void timelineSnapChanged();
     void timelineCenterPlayheadChanged();
     void timelineScrollZoomChanged();
+    void timelineFramebufferWaveformChanged();
     void playerAudioChannelsChanged(int);
     void playerGpuChanged();
     void audioInDurationChanged();
