@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2020 Meltytech, LLC
+ * Copyright (c) 2014-2021 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ public:
     static bool warnIfNotWritable(const QString& filePath, QWidget* parent, const QString& caption);
     static QString producerTitle(const Mlt::Producer& producer);
     static QString removeFileScheme(QUrl &url);
-    static QStringList sortedFileList(const QList<QUrl>& urls);
+    static const QStringList sortedFileList(const QList<QUrl>& urls);
     static int coerceMultiple(int value, int multiple = 2);
     static QList<QUrl> expandDirectories(const QList<QUrl>& urls);
     static bool isDecimalPoint(QChar ch);
