@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2020 Meltytech, LLC
+ * Copyright (c) 2012-2021 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -329,7 +329,6 @@ void AvformatProducerWidget::onFrameDecoded()
     bool populateTrackCombos = (ui->videoTrackComboBox->count() == 0 &&
                                 ui->audioTrackComboBox->count() == 0);
     int color_range = !qstrcmp(m_producer->get("meta.media.color_range"), "full");
-    bool isAV1 = false;
 
     for (int i = 0; i < n; i++) {
         QString key = QString("meta.media.%1.stream.type").arg(i);
@@ -352,13 +351,8 @@ void AvformatProducerWidget::onFrameDecoded()
                 ui->videoTrackComboBox->addItem(name, i);
             }
             if (i == m_producer->get_int("video_index")) {
-                key = QString("meta.media.%1.codec.name").arg(i);
-                QString codec(m_producer->get(key.toLatin1().constData()));
-                if (codec == "libdav1d") {
-                    isAV1 = true;
-                }
                 key = QString("meta.media.%1.codec.long_name").arg(i);
-                codec = QString::fromUtf8(m_producer->get(key.toLatin1().constData()));
+                QString codec(m_producer->get(key.toLatin1().constData()));
                 ui->videoTableWidget->setItem(0, 1, new QTableWidgetItem(codec));
                 key = QString("meta.media.%1.codec.pix_fmt").arg(i);
                 QString pix_fmt = QString::fromLatin1(m_producer->get(key.toLatin1().constData()));
@@ -369,6 +363,42 @@ void AvformatProducerWidget::onFrameDecoded()
                     ui->rangeComboBox->setEnabled(false);
                 }
                 ui->videoTableWidget->setItem(3, 1, new QTableWidgetItem(pix_fmt));
+                key = QString("meta.media.%1.codec.colorspace").arg(i);
+                int colorspace = m_producer->get_int(key.toLatin1().constData());
+                QString csString = tr("unknown (%1)").arg(colorspace);
+                switch (colorspace) {
+                    case 240:
+                        csString = "SMPTE ST240";
+                        break;
+                    case 601:
+                        csString = "ITU-R BT.601";
+                        break;
+                    case 709:
+                        csString = "ITU-R BT.709";
+                        break;
+                    case 9:
+                    case 10:
+                        csString = "ITU-R BT.2020";
+                        break;
+                }
+                ui->videoTableWidget->setItem(4, 1, new QTableWidgetItem(csString));
+                key = QString("meta.media.%1.codec.color_trc").arg(i);
+                int trc = m_producer->get_int(key.toLatin1().constData());
+                QString trcString = tr("unknown (%1)").arg(trc);
+                switch (trc) {
+                    case 0: trcString = tr("NA"); break;
+                    case 1: trcString = "ITU-R BT.709"; break;
+                    case 6: trcString = "ITU-R BT.601"; break;
+                    case 7: trcString = "SMPTE ST240"; break;
+                    case 14: trcString = "ITU-R BT.2020"; break;
+                    case 15: trcString = "ITU-R BT.2020"; break;
+                    case 16: trcString = "SMPTE ST2084 (PQ)"; break;
+                    case 17: trcString = "SMPTE ST428"; break;
+                    case 18: trcString = "ARIB B67 (HLG)"; break;
+                }
+                QTableWidgetItem* trcItem = new QTableWidgetItem(trcString);
+                trcItem->setData(Qt::UserRole, QVariant(trc));
+                ui->videoTableWidget->setItem(5, 1, trcItem);
                 ui->videoTrackComboBox->setCurrentIndex(videoIndex);
             }
             ui->tabWidget->setTabEnabled(0, true);
@@ -432,6 +462,8 @@ void AvformatProducerWidget::onFrameDecoded()
         ui->videoTableWidget->setItem(1, 1, new QTableWidgetItem(""));
         ui->videoTableWidget->setItem(2, 1, new QTableWidgetItem(""));
         ui->videoTableWidget->setItem(3, 1, new QTableWidgetItem(""));
+        ui->videoTableWidget->setItem(4, 1, new QTableWidgetItem(""));
+        ui->videoTableWidget->setItem(5, 1, new QTableWidgetItem(""));
         ui->proxyButton->hide();
     }
 
@@ -526,17 +558,20 @@ void AvformatProducerWidget::onFrameDecoded()
     ui->syncSlider->setValue(qRound(m_producer->get_double("video_delay") * 1000.0));
 
     if (Settings.showConvertClipDialog() && !m_producer->get_int(kShotcutSkipConvertProperty)) {
-        if (isAV1) {
+        if (ui->videoTableWidget->item(5, 1)->data(Qt::UserRole).toInt() > 7) {
+            // Transfer characteristics > SMPTE240M Probably need conversion
+            QString trcString = ui->videoTableWidget->item(5, 1)->text();
             m_producer->set(kShotcutSkipConvertProperty, true);
             LongUiTask::cancel();
             MLT.pause();
-            LOG_INFO() << resource << "uses AV1 video codec";
-            TranscodeDialog dialog(tr("This file uses the AV1 video codec, which is not reliable for editing. "
+            LOG_INFO() << resource << "Probable HDR" << ui->videoTableWidget->item(5, 1)->text();
+            TranscodeDialog dialog(tr("This file uses color transfer characteristics %1, which may result in incorrect colors or brightness in Shotcut. "
                                       "Do you want to convert it to an edit-friendly format?\n\n"
                                       "If yes, choose a format below and then click OK to choose a file name. "
                                       "After choosing a file name, a job is created. "
-                                      "When it is done, double-click the job to open it.\n"),
-                                   ui->scanComboBox->currentIndex(), this);
+                                      "When it is done, double-click the job to open it.\n").arg(trcString),
+                                      ui->scanComboBox->currentIndex(), this);
+            dialog.set709Convert(true);
             dialog.setWindowModality(QmlApplication::dialogModality());
             dialog.showCheckBox();
             convert(dialog);
@@ -554,7 +589,7 @@ void AvformatProducerWidget::onFrameDecoded()
             dialog.setWindowModality(QmlApplication::dialogModality());
             dialog.showCheckBox();
             convert(dialog);
-        } else if (!MLT.isSeekable(m_producer.data())) {
+        } else if (QFile::exists(resource) && !MLT.isSeekable(m_producer.data())) {
             m_producer->set(kShotcutSkipConvertProperty, true);
             LongUiTask::cancel();
             MLT.pause();
@@ -758,6 +793,7 @@ void AvformatProducerWidget::on_actionFFmpegConvert_triggered()
                               "When it is done, double-click the job to open it.\n"),
                            ui->scanComboBox->currentIndex(), this);
     dialog.setWindowModality(QmlApplication::dialogModality());
+    dialog.set709Convert(ui->videoTableWidget->item(5, 1)->data(Qt::UserRole).toInt() > 7);
     convert(dialog);
 }
 
@@ -782,11 +818,37 @@ void AvformatProducerWidget::convert(TranscodeDialog& dialog)
         else
             args << "-map" << "0:a?" << "-map" << "0:V?";
         args << "-map_metadata" << "0" << "-ignore_unknown";
+
+        // Set video filters
+        args << "-vf";
+        QString filterString;
+        if (dialog.deinterlace()) {
+            QString deinterlaceFilter = QString("bwdif,");
+            filterString = filterString + deinterlaceFilter;
+        }
+        QString range;
         if (ui->rangeComboBox->currentIndex())
-            args << "-vf" << "scale=flags=accurate_rnd+full_chroma_inp+full_chroma_int:in_range=full:out_range=full" << "-color_range" << "jpeg";
+            range = "full";
         else
-            args << "-vf" << "scale=flags=accurate_rnd+full_chroma_inp+full_chroma_int:in_range=mpeg:out_range=mpeg" << "-color_range" << "mpeg";
-        if (!ui->scanComboBox->currentIndex())
+            range = "mpeg";
+        if (dialog.get709Convert()) {
+            QString convertFilter = QString("zscale=t=linear:npl=100,format=gbrpf32le,zscale=p=bt709,tonemap=tonemap=hable:desat=0,zscale=t=bt709:m=bt709:r=tv,format=yuv422p,");
+            filterString = filterString + convertFilter;
+        }
+        filterString = filterString + QString("scale=flags=accurate_rnd+full_chroma_inp+full_chroma_int:in_range=%1:out_range=%2").arg(range).arg(range);
+        if (dialog.fpsOverride()) {
+            QString minterpFilter = QString(",minterpolate='mi_mode=%1:mc_mode=aobmc:me_mode=bidir:vsbmc=1:fps=%2'").arg(dialog.frc()).arg(dialog.fps());
+            filterString = filterString + minterpFilter;
+        }
+        args << filterString;
+
+        // Specify color range
+        if (ui->rangeComboBox->currentIndex())
+            args << "-color_range" << "jpeg";
+        else
+            args << "-color_range" << "mpeg";
+
+        if (!dialog.deinterlace() && !ui->scanComboBox->currentIndex())
             args << "-flags" << "+ildct+ilme" << "-top" << QString::number(ui->fieldOrderComboBox->currentIndex());
 
         switch (dialog.format()) {
@@ -794,11 +856,11 @@ void AvformatProducerWidget::convert(TranscodeDialog& dialog)
             path.append("/%1 - %2.mp4");
             nameFilter = tr("MP4 (*.mp4);;All Files (*)");
             args << "-f" << "mp4" << "-codec:a" << "ac3" << "-b:a" << "512k" << "-codec:v" << "libx264";
-            args << "-preset" << "medium" << "-g" << "1" << "-crf" << "11";
+            args << "-preset" << "medium" << "-g" << "1" << "-crf" << "15";
             break;
         case 1:
             args << "-f" << "mov" << "-codec:a" << "alac";
-            if (ui->scanComboBox->currentIndex()) { // progressive
+            if (dialog.deinterlace() || ui->scanComboBox->currentIndex()) { // progressive
                 args << "-codec:v" << "dnxhd" << "-profile:v" << "dnxhr_hq" << "-pix_fmt" << "yuv422p";
             } else { // interlaced
                 args << "-codec:v" << "prores_ks" << "-profile:v" << "standard";
@@ -813,6 +875,9 @@ void AvformatProducerWidget::convert(TranscodeDialog& dialog)
             nameFilter = tr("MKV (*.mkv);;All Files (*)");
             break;
         }
+        if (dialog.get709Convert()) {
+            args << "-colorspace" << "bt709" << "-color_primaries" << "bt709" << "-color_trc" << "bt709";
+        }
         QFileInfo fi(resource);
         path = path.arg(fi.completeBaseName()).arg(tr("Converted"));
         QString filename = QFileDialog::getSaveFileName(this, dialog.windowTitle(), path, nameFilter,
